@@ -12,7 +12,7 @@ use Scalar::Util;
 
 use parent 'Exporter';
 
-our $VERSION = '0.54'; # VERSION
+our $VERSION = '0.55'; # VERSION
 
 our @EXPORT = @Data::Object::Syntax::EXPORT;
 
@@ -32,13 +32,13 @@ Data::Object::Class::Syntax - Class Declaration DSL for Perl 5
 
 =head1 VERSION
 
-version 0.54
+version 0.55
 
 =head1 SYNOPSIS
 
     package Person;
 
-    use namespace::autoclean;
+    use namespace::autoclean -except => 'has';
 
     use Data::Object::Class;
     use Data::Object::Class::Syntax;
