@@ -12,7 +12,7 @@ use Sub::Quote;
 
 use parent 'Exporter';
 
-our $VERSION = '0.54'; # VERSION
+our $VERSION = '0.55'; # VERSION
 
 our @EXPORT = qw(
     alt
@@ -45,13 +45,6 @@ sub import {
     my $class  = $_[0];
     my $target = caller;
 
-    unless ($target->can('BUILD')) {
-        no strict 'refs';
-        no warnings 'redefine';
-
-        *{"${target}::BUILD"} = sub { shift };
-    }
-
     if (my $orig = $target->can('has')) {
         no strict 'refs';
         no warnings 'redefine';
@@ -263,7 +256,7 @@ Data::Object::Syntax - Object Syntax DSL for Perl 5
 
 =head1 VERSION
 
-version 0.54
+version 0.55
 
 =head1 SYNOPSIS
 
